.. _api_geometry_n_box:

.. currentmodule:: microstructpy.geometry.n_box

microstructpy.geometry.n_box.NBox
=================================

.. autoclass:: NBox
    :members:
    :undoc-members:
    :inherited-members:
    :show-inheritance: